==> zhongyan-activity-service-api-1.0.3-20211130.112736-56-sources.jar: cn/com/duiba/zhongyan/activity/service/api/param/QuestionAnswerParam.java <==
package cn.com.duiba.zhongyan.activity.service.api.param;

import java.util.List;

/**
 * @author LuHui
 * @description
 * @date 2021/11/26  13:43
 */
public class QuestionAnswerParam {
    /**
     * 题目id
     */
    private String questionId;
    /**
     * 题目类型 （0:单选题 1:多选题 2:填空题）
     */
    private Integer type;
    /**
     * 标题
     */
    private String title;
    /**
     * 题目必填状态（0 必填 1不必填）
     */
    private Integer questionTipStatus;
    /**
     * 填空题提示语
     */
    private String questionTip;
    /**
     *选择题
     */
    private List<OptionParam> option;
    /**
     * 答案
     */
    private List<AnswerParam> answerList;


    public String getQuestionId() {
        return questionId;
    }

    public void setQuestionId(String questionId) {
        this.questionId = questionId;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getQuestionTipStatus() {
        return questionTipStatus;
    }

    public void setQuestionTipStatus(Integer questionTipStatus) {
        this.questionTipStatus = questionTipStatus;
    }

    public String getQuestionTip() {
        return questionTip;
    }

    public void setQuestionTip(String questionTip) {
        this.questionTip = questionTip;
    }


    public List<OptionParam> getOption() {
        return option;
    }

    public void setOption(List<OptionParam> option) {
        this.option = option;
    }

    public List<AnswerParam> getAnswerList() {
        return answerList;
    }

    public void setAnswerList(List<AnswerParam> answerList) {
        this.answerList = answerList;
    }
}

==> zhongyan-activity-service-api-1.0.3-20211203.125705-173-sources.jar: cn/com/duiba/zhongyan/activity/service/api/param/QuestionAnswerParam.java <==
package cn.com.duiba.zhongyan.activity.service.api.param;

import java.io.Serializable;
import java.util.List;

/**
 * @author LuHui
 * @description
 * @date 2021/11/26  13:43
 */
public class QuestionAnswerParam implements Serializable {
    private static final long serialVersionUID = -6028126546661676303L;
    /**
     * 题目id
     */
    private String questionId;
    /**
     * 题目类型 （0:单选题 1:多选题 2:填空题）
     */
    private Integer type;
    /**
     * 标题
     */
    private String title;
    /**
     * 题目必填状态（0 必填 1不必填）
     */
    private Integer questionTipStatus;
    /**
     * 填空题提示语
     */
    private String questionTip;
    /**
     *选择题
     */
    private List<OptionParam> option;
    /**
     * 答案
     */
    private List<AnswerParam> answerList;


    public String getQuestionId() {
        return questionId;
    }

    public void setQuestionId(String questionId) {
        this.questionId = questionId;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getQuestionTipStatus() {
        return questionTipStatus;
    }

    public void setQuestionTipStatus(Integer questionTipStatus) {
        this.questionTipStatus = questionTipStatus;
    }

    public String getQuestionTip() {
        return questionTip;
    }

    public void setQuestionTip(String questionTip) {
        this.questionTip = questionTip;
    }


    public List<OptionParam> getOption() {
        return option;
    }

    public void setOption(List<OptionParam> option) {
        this.option = option;
    }

    public List<AnswerParam> getAnswerList() {
        return answerList;
    }

    public void setAnswerList(List<AnswerParam> answerList) {
        this.answerList = answerList;
    }
}
